==> istio-model-v1alpha3-6.3.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionDelayFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Double;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface HTTPFaultInjectionDelayFluent<A extends HTTPFaultInjectionDelayFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildHttpDelayType instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsHTTPFaultInjectionDelayHttpDelayType getHttpDelayType();
  public IsHTTPFaultInjectionDelayHttpDelayType buildHttpDelayType();
  public A withHttpDelayType(IsHTTPFaultInjectionDelayHttpDelayType httpDelayType);
  public Boolean hasHttpDelayType();
  public A withHTTPFaultInjectionDelayFixedHttpType(HTTPFaultInjectionDelayFixedDelay hTTPFaultInjectionDelayFixedHttpType);
  public HTTPFaultInjectionDelayFluent.HTTPFaultInjectionDelayFixedHttpTypeNested<A> withNewHTTPFaultInjectionDelayFixedHttpType();
  public HTTPFaultInjectionDelayFluent.HTTPFaultInjectionDelayFixedHttpTypeNested<A> withNewHTTPFaultInjectionDelayFixedHttpTypeLike(HTTPFaultInjectionDelayFixedDelay item);
  public A withNewHTTPFaultInjectionDelayFixedHttpType(String fixedDelay);
  public A withHTTPFaultInjectionDelayExponentialHttpType(HTTPFaultInjectionDelayExponentialDelay hTTPFaultInjectionDelayExponentialHttpType);
  public HTTPFaultInjectionDelayFluent.HTTPFaultInjectionDelayExponentialHttpTypeNested<A> withNewHTTPFaultInjectionDelayExponentialHttpType();
  public HTTPFaultInjectionDelayFluent.HTTPFaultInjectionDelayExponentialHttpTypeNested<A> withNewHTTPFaultInjectionDelayExponentialHttpTypeLike(HTTPFaultInjectionDelayExponentialDelay item);
  public A withNewHTTPFaultInjectionDelayExponentialHttpType(String exponentialDelay);
  public Integer getPercent();
  public A withPercent(Integer percent);
  public Boolean hasPercent();
  
  /**
   * This method has been deprecated, please use method buildPercentage instead.
   * @return The buildable object.
   */
  @Deprecated
  public Percent getPercentage();
  public Percent buildPercentage();
  public A withPercentage(Percent percentage);
  public Boolean hasPercentage();
  public A withNewPercentage(Double value);
  public HTTPFaultInjectionDelayFluent.PercentageNested<A> withNewPercentage();
  public HTTPFaultInjectionDelayFluent.PercentageNested<A> withNewPercentageLike(Percent item);
  public HTTPFaultInjectionDelayFluent.PercentageNested<A> editPercentage();
  public HTTPFaultInjectionDelayFluent.PercentageNested<A> editOrNewPercentage();
  public HTTPFaultInjectionDelayFluent.PercentageNested<A> editOrNewPercentageLike(Percent item);
  public interface HTTPFaultInjectionDelayFixedHttpTypeNested<N> extends Nested<N>,HTTPFaultInjectionDelayFixedDelayFluent<HTTPFaultInjectionDelayFluent.HTTPFaultInjectionDelayFixedHttpTypeNested<N>>{
    public N and();
    public N endHTTPFaultInjectionDelayFixedHttpType();
    
  }
  public interface HTTPFaultInjectionDelayExponentialHttpTypeNested<N> extends Nested<N>,HTTPFaultInjectionDelayExponentialDelayFluent<HTTPFaultInjectionDelayFluent.HTTPFaultInjectionDelayExponentialHttpTypeNested<N>>{
    public N and();
    public N endHTTPFaultInjectionDelayExponentialHttpType();
    
  }
  public interface PercentageNested<N> extends Nested<N>,PercentFluent<HTTPFaultInjectionDelayFluent.PercentageNested<N>>{
    public N and();
    public N endPercentage();
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionDelayFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Double;
import java.lang.Integer;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface HTTPFaultInjectionDelayFluent<A extends HTTPFaultInjectionDelayFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildHttpDelayType instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsHTTPFaultInjectionDelayHttpDelayType getHttpDelayType();
  public IsHTTPFaultInjectionDelayHttpDelayType buildHttpDelayType();
  public A withHttpDelayType(IsHTTPFaultInjectionDelayHttpDelayType httpDelayType);
  public Boolean hasHttpDelayType();
  public A withHTTPFaultInjectionDelayFixedHttpType(HTTPFaultInjectionDelayFixedDelay hTTPFaultInjectionDelayFixedHttpType);
  public HTTPFaultInjectionDelayFluent.HTTPFaultInjectionDelayFixedHttpTypeNested<A> withNewHTTPFaultInjectionDelayFixedHttpType();
  public HTTPFaultInjectionDelayFluent.HTTPFaultInjectionDelayFixedHttpTypeNested<A> withNewHTTPFaultInjectionDelayFixedHttpTypeLike(HTTPFaultInjectionDelayFixedDelay item);
  public A withNewHTTPFaultInjectionDelayFixedHttpType(String fixedDelay);
  public A withHTTPFaultInjectionDelayExponentialHttpType(HTTPFaultInjectionDelayExponentialDelay hTTPFaultInjectionDelayExponentialHttpType);
  public HTTPFaultInjectionDelayFluent.HTTPFaultInjectionDelayExponentialHttpTypeNested<A> withNewHTTPFaultInjectionDelayExponentialHttpType();
  public HTTPFaultInjectionDelayFluent.HTTPFaultInjectionDelayExponentialHttpTypeNested<A> withNewHTTPFaultInjectionDelayExponentialHttpTypeLike(HTTPFaultInjectionDelayExponentialDelay item);
  public A withNewHTTPFaultInjectionDelayExponentialHttpType(String exponentialDelay);
  public Integer getPercent();
  public A withPercent(Integer percent);
  public Boolean hasPercent();
  
  /**
   * This method has been deprecated, please use method buildPercentage instead.
   * @return The buildable object.
   */
  @Deprecated
  public Percent getPercentage();
  public Percent buildPercentage();
  public A withPercentage(Percent percentage);
  public Boolean hasPercentage();
  public A withNewPercentage(Double value);
  public HTTPFaultInjectionDelayFluent.PercentageNested<A> withNewPercentage();
  public HTTPFaultInjectionDelayFluent.PercentageNested<A> withNewPercentageLike(Percent item);
  public HTTPFaultInjectionDelayFluent.PercentageNested<A> editPercentage();
  public HTTPFaultInjectionDelayFluent.PercentageNested<A> editOrNewPercentage();
  public HTTPFaultInjectionDelayFluent.PercentageNested<A> editOrNewPercentageLike(Percent item);
  public interface HTTPFaultInjectionDelayFixedHttpTypeNested<N> extends Nested<N>,HTTPFaultInjectionDelayFixedDelayFluent<HTTPFaultInjectionDelayFluent.HTTPFaultInjectionDelayFixedHttpTypeNested<N>>{
    public N and();
    public N endHTTPFaultInjectionDelayFixedHttpType();
    
  }
  public interface HTTPFaultInjectionDelayExponentialHttpTypeNested<N> extends Nested<N>,HTTPFaultInjectionDelayExponentialDelayFluent<HTTPFaultInjectionDelayFluent.HTTPFaultInjectionDelayExponentialHttpTypeNested<N>>{
    public N and();
    public N endHTTPFaultInjectionDelayExponentialHttpType();
    
  }
  public interface PercentageNested<N> extends Nested<N>,PercentFluent<HTTPFaultInjectionDelayFluent.PercentageNested<N>>{
    public N and();
    public N endPercentage();
    
  }
  
}
